==> dojo-1.8.1-javadoc.jar: dojo/cldr/nls/fr/gregorian.js.uncompressed.js <==
define(
"dojo/cldr/nls/fr/gregorian", //begin v1.x content
{
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-format-narrow": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dayPeriods-format-abbr-am": "AM",
	"dayPeriods-format-abbr-pm": "PM",
	"dayPeriods-format-narrow-pm": "p",
	"dayPeriods-format-wide-afternoon": "après-midi",
	"dayPeriods-format-wide-am": "AM",
	"dayPeriods-format-wide-morning": "matin",
	"dayPeriods-format-wide-night": "soir",
	"dayPeriods-format-wide-noon": "midi",
	"dayPeriods-format-wide-pm": "PM",
	"eraNames": [
		"avant Jésus-Christ",
		"après Jésus-Christ"
	],
	"eraAbbr": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"dateFormat-full": "EEEE d MMMM y",
	"dateFormat-long": "d MMMM y",
	"dateFormat-medium": "d MMM y",
	"dateFormat-short": "dd/MM/yy",
	"timeFormat-full": "HH:mm:ss zzzz",
	"timeFormat-long": "HH:mm:ss z",
	"timeFormat-medium": "HH:mm:ss",
	"timeFormat-short": "HH:mm",
	"dateFormatItem-d": "d",
	"dateFormatItem-Ed": "E d",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-M": "L",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-MEd": "E d/M",
	"dateFormatItem-MMd": "d/MM",
	"dateFormatItem-MMdd": "dd/MM",
	"dateFormatItem-MMM": "LLL",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MMMdd": "dd MMM",
	"dateFormatItem-MMMEd": "E d MMM",
	"dateFormatItem-MMMMEd": "E d MMMM",
	"dateFormatItem-ms": "mm:ss",
	"dateFormatItem-y": "y",
	"dateFormatItem-yM": "M/yyyy",
	"dateFormatItem-yMd": "d/M/yyyy",
	"dateFormatItem-yMEd": "E d/M/yyyy",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yMMMd": "d MMM y",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"dateFormatItem-yQ": "'T'Q y",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yyMM": "MM/yy",
	"dateFormatItem-yyMMM": "MMM yy",
	"dateFormatItem-yyMMMd": "d MMM yy",
	"dateFormatItem-yyMMMEd": "E d MMM yy",
	"dateFormatItem-yyQ": "'T'Q yy",
	"dateFormatItem-yyQQQQ": "QQQQ yy",
	"dateFormatItem-yyyyMMMM": "MMMM y",
	"field-era": "ère",
	"field-year": "année",
	"field-year-relative+-1": "l’année dernière",
	"field-year-relative+0": "cette année",
	"field-year-relative+1": "l’année prochaine",
	"field-month": "mois",
	"field-month-relative+-1": "le mois dernier",
	"field-month-relative+0": "ce mois-ci",
	"field-month-relative+1": "le mois prochain",
	"field-week": "semaine",
	"field-week-relative+-1": "la semaine dernière",
	"field-week-relative+0": "cette semaine",
	"field-week-relative+1": "la semaine prochaine",
	"field-day": "jour",
	"field-day-relative+-2": "avant-hier",
	"field-day-relative+-1": "hier",
	"field-day-relative+0": "aujourd’hui",
	"field-day-relative+1": "demain",
	"field-day-relative+2": "après-demain",
	"field-weekday": "jour de la semaine",
	"field-dayperiod": "cadran",
	"field-hour": "heure",
	"field-minute": "minute",
	"field-second": "seconde",
	"field-zone": "fuseau horaire",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"eraNarrow": [
		"av. J.-C.",
		"ap. J.-C."
	]
}
//end v1.x content
);

==> dojo-1.8.3-javadoc.jar: dojo/cldr/nls/fr/gregorian.js.uncompressed.js <==
define(
"dojo/cldr/nls/fr/gregorian", //begin v1.x content
{
	"days-standAlone-short": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "jour de la semaine",
	"dateFormatItem-yyQQQQ": "QQQQ yy",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yyMMMEd": "E d MMM yy",
	"dateFormatItem-yMEd": "E d/M/yyyy",
	"dateFormatItem-MMMEd": "E d MMM",
	"eraNarrow": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"dayPeriods-format-wide-morning": "matin",
	"dateFormatItem-MMMdd": "dd MMM",
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"dateFormat-long": "d MMMM y",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE d MMMM y",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "AM",
	"dayPeriods-format-wide-noon": "midi",
	"dateFormatItem-yMd": "d/M/yyyy",
	"field-era": "ère",
	"dateFormatItem-yM": "M/yyyy",
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "année",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yQ": "'T'Q y",
	"dateFormatItem-yyyyMMMM": "MMMM y",
	"field-hour": "heure",
	"dateFormatItem-MMdd": "dd/MM",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"dateFormatItem-yyQ": "'T'Q yy",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dayPeriods-format-narrow-morning": "matin",
	"field-day-relative+0": "aujourd’hui",
	"field-day-relative+1": "demain",
	"field-day-relative+2": "après-demain",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"dateFormatItem-yyMMM": "MMM yy",
	"timeFormat-medium": "HH:mm:ss",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"eraAbbr": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"field-minute": "minute",
	"field-dayperiod": "cadran",
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dayPeriods-format-wide-night": "soir",
	"dateFormatItem-yyMMMd": "d MMM yy",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "hier",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "avant-hier",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-day": "jour",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-zone": "fuseau horaire",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "l’année dernière",
	"dayPeriods-format-narrow-night": "soir",
	"field-month-relative+-1": "le mois dernier",
	"dateFormatItem-yyMM": "MM/yy",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-format-abbr-pm": "PM",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"eraNames": [
		"avant Jésus-Christ",
		"après Jésus-Christ"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "mois",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-MMMMEd": "E d MMMM",
	"dateFormat-short": "dd/MM/yy",
	"dateFormatItem-MMd": "d/MM",
	"dayPeriods-format-wide-afternoon": "après-midi",
	"dayPeriods-format-narrow-noon": "midi",
	"field-second": "seconde",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"field-month-relative+0": "ce mois-ci",
	"field-month-relative+1": "le mois prochain",
	"dateFormatItem-Ed": "E d",
	"field-week": "semaine",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "cette année",
	"field-week-relative+-1": "la semaine dernière",
	"field-year-relative+1": "l’année prochaine",
	"dayPeriods-format-narrow-pm": "p",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-week-relative+0": "cette semaine",
	"field-week-relative+1": "la semaine prochaine"
}
//end v1.x content
);
